import { ICookies, IFlag, IFlags, TTagValue } from './interfaces';
import { FLAGS } from './enums';
export declare class FCS {
    /**
     * Constants of flags and their integers
     */
    static FLAG_INACTIVE: FLAGS;
    static FLAG_ACTIVE: FLAGS;
    static FLAG_COOKIE: FLAGS;
    static FLAG_TAG: FLAGS;
    static FLAG_MULTI_AND: FLAGS;
    static FLAG_MULTI_OR: FLAGS;
    /**
     * Variable with configuration data
     */
    private config;
    /**
     * In-memory cache with results of resolving flags for features
     */
    private cache;
    /**
     * Clear in-memory cache
     */
    clearCache(): void;
    /**
     * Turn slashes into double dashes
     * @param name
     */
    turnSlashesIntoDoubleDashes(name: string): string;
    /**
     * Sets tag's name and value
     * @param name
     * @param value
     */
    setTag(name: string, value: TTagValue): void;
    /**
     * Set list of features with details of flags
     * @param flags
     */
    setFlags(flags: IFlags): void;
    /**
     * Set cookies
     * @param cookies
     */
    setCookies(cookies: ICookies): void;
    /**
     * Returns list of active features
     */
    getActiveFeatures(): string[];
    /**
     * Returns list of CSS classes for frontend for <body> element
     * @param features
     */
    getBodyCssClasses(features?: string[]): string;
    /**
     * Checks if feature is active
     * @param name
     */
    feature(name: string): boolean;
    /**
     * Validates flag details to check if feature is active
     * @param name
     * @param flag
     */
    isFlagActive(name: string, flag: IFlag): boolean;
}
