"use strict";
var __values = (this && this.__values) || function (o) {
    var m = typeof Symbol === "function" && o[Symbol.iterator], i = 0;
    if (m) return m.call(o);
    return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
};
Object.defineProperty(exports, "__esModule", { value: true });
var enums_1 = require("./enums");
var FCS = /** @class */ (function () {
    function FCS() {
        /**
         * Variable with configuration data
         */
        this.config = {
            tags: {
                env: 'staging',
                username: '',
                ip: '0.0.0.0',
                role: '',
            },
            cookies: {},
            flags: {},
        };
        /**
         * In-memory cache with results of resolving flags for features
         */
        this.cache = {};
    }
    /**
     * Clear in-memory cache
     */
    FCS.prototype.clearCache = function () {
        this.cache = {};
    };
    /**
     * Turn slashes into double dashes
     * @param name
     */
    FCS.prototype.turnSlashesIntoDoubleDashes = function (name) {
        return name.replace(/\//g, '--');
    };
    /**
     * Sets tag's name and value
     * @param name
     * @param value
     */
    FCS.prototype.setTag = function (name, value) {
        this.config.tags[name] = value;
        this.clearCache();
    };
    /**
     * Set list of features with details of flags
     * @param flags
     */
    FCS.prototype.setFlags = function (flags) {
        this.config.flags = flags;
        this.clearCache();
    };
    /**
     * Set cookies
     * @param cookies
     */
    FCS.prototype.setCookies = function (cookies) {
        this.config.cookies = cookies;
        this.clearCache();
    };
    /**
     * Returns list of active features
     */
    FCS.prototype.getActiveFeatures = function () {
        var activeFeatures = [];
        for (var name in this.config.flags) {
            if (this.feature(name)) {
                activeFeatures.push(name);
            }
        }
        return activeFeatures;
    };
    /**
     * Returns list of CSS classes for frontend for <body> element
     * @param features
     */
    FCS.prototype.getBodyCssClasses = function (features) {
        var e_1, _a;
        if (features === void 0) { features = this.getActiveFeatures(); }
        var bodyClasses = '';
        try {
            for (var features_1 = __values(features), features_1_1 = features_1.next(); !features_1_1.done; features_1_1 = features_1.next()) {
                var feature = features_1_1.value;
                bodyClasses +=
                    (bodyClasses ? ' ' : '') +
                        'fcs-' +
                        this.turnSlashesIntoDoubleDashes(feature);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (features_1_1 && !features_1_1.done && (_a = features_1.return)) _a.call(features_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return bodyClasses;
    };
    /**
     * Checks if feature is active
     * @param name
     */
    FCS.prototype.feature = function (name) {
        if (this.cache[name] !== undefined) {
            return this.cache[name];
        }
        else {
            var flag = this.config.flags[name];
            if (flag) {
                return (this.cache[name] = this.isFlagActive(name, flag));
            }
            else {
                return false;
            }
        }
    };
    /**
     * Validates flag details to check if feature is active
     * @param name
     * @param flag
     */
    FCS.prototype.isFlagActive = function (name, flag) {
        var e_2, _a, e_3, _b;
        if (flag && flag.flag !== undefined) {
            switch (flag.flag) {
                case FCS.FLAG_INACTIVE:
                    return false;
                case FCS.FLAG_ACTIVE:
                    return true;
                case FCS.FLAG_COOKIE:
                    return Boolean(this.config.cookies['fcs-' + this.turnSlashesIntoDoubleDashes(name)]);
                case FCS.FLAG_TAG:
                    return (flag.name !== undefined &&
                        flag.value !== undefined &&
                        this.config.tags[flag.name] !== undefined &&
                        (Array.isArray(flag.value)
                            ? flag.value.indexOf(this.config.tags[flag.name]) !== -1
                            : this.config.tags[flag.name] === flag.value));
                case FCS.FLAG_MULTI_AND:
                    if (flag.flags && flag.flags.length) {
                        try {
                            for (var _c = __values(flag.flags), _d = _c.next(); !_d.done; _d = _c.next()) {
                                var sub_flag = _d.value;
                                if (!this.isFlagActive(name, sub_flag)) {
                                    return false;
                                }
                            }
                        }
                        catch (e_2_1) { e_2 = { error: e_2_1 }; }
                        finally {
                            try {
                                if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
                            }
                            finally { if (e_2) throw e_2.error; }
                        }
                        return true;
                    }
                    return false;
                case FCS.FLAG_MULTI_OR:
                    if (flag.flags && flag.flags.length) {
                        try {
                            for (var _e = __values(flag.flags), _f = _e.next(); !_f.done; _f = _e.next()) {
                                var sub_flag = _f.value;
                                if (this.isFlagActive(name, sub_flag)) {
                                    return true;
                                }
                            }
                        }
                        catch (e_3_1) { e_3 = { error: e_3_1 }; }
                        finally {
                            try {
                                if (_f && !_f.done && (_b = _e.return)) _b.call(_e);
                            }
                            finally { if (e_3) throw e_3.error; }
                        }
                    }
                    return false;
            }
        }
        return false;
    };
    /**
     * Constants of flags and their integers
     */
    FCS.FLAG_INACTIVE = enums_1.FLAGS.INACTIVE;
    FCS.FLAG_ACTIVE = enums_1.FLAGS.ACTIVE;
    FCS.FLAG_COOKIE = enums_1.FLAGS.COOKIE;
    FCS.FLAG_TAG = enums_1.FLAGS.TAG;
    FCS.FLAG_MULTI_AND = enums_1.FLAGS.MULTI_AND;
    FCS.FLAG_MULTI_OR = enums_1.FLAGS.MULTI_OR;
    return FCS;
}());
exports.FCS = FCS;
