"use strict";
var __values = (this && this.__values) || function (o) {
    var m = typeof Symbol === "function" && o[Symbol.iterator], i = 0;
    if (m) return m.call(o);
    return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
};
Object.defineProperty(exports, "__esModule", { value: true });
var FCSClient = /** @class */ (function () {
    function FCSClient() {
        /**
         * Variable with array of active features
         */
        this.activeFeatures = [];
    }
    /**
     * Turn slashes into double dashes
     * @param name
     */
    FCSClient.prototype.turnSlashesIntoDoubleDashes = function (name) {
        return name.replace(/\//g, '--');
    };
    /**
     * Set list of active features
     * @param features
     */
    FCSClient.prototype.setActiveFeatures = function (features) {
        this.activeFeatures = features;
    };
    /**
     * Get list of active features
     */
    FCSClient.prototype.getActiveFeatures = function () {
        return this.activeFeatures;
    };
    /**
     * Returns list of CSS classes for frontend for <body> element
     * @param features
     */
    FCSClient.prototype.getBodyCssClasses = function (features) {
        var e_1, _a;
        if (features === void 0) { features = this.getActiveFeatures(); }
        var bodyClasses = '';
        try {
            for (var features_1 = __values(features), features_1_1 = features_1.next(); !features_1_1.done; features_1_1 = features_1.next()) {
                var feature = features_1_1.value;
                bodyClasses +=
                    (bodyClasses ? ' ' : '') +
                        'fcs-' +
                        this.turnSlashesIntoDoubleDashes(feature);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (features_1_1 && !features_1_1.done && (_a = features_1.return)) _a.call(features_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return bodyClasses;
    };
    /**
     * Checks if feature is active
     * @param name
     */
    FCSClient.prototype.feature = function (name) {
        return this.getActiveFeatures().indexOf(name) !== -1;
    };
    /**
     * Checks if any of multiple features is active
     * @param name
     */
    FCSClient.prototype.multiFeature = function (name) {
        var e_2, _a;
        var names = Array.isArray(name)
            ? name
            : name.indexOf(',') !== -1
                ? name.split(',')
                : false;
        if (!names && typeof name === 'string') {
            return this.feature(name);
        }
        else {
            try {
                for (var names_1 = __values(names), names_1_1 = names_1.next(); !names_1_1.done; names_1_1 = names_1.next()) {
                    var sub_name = names_1_1.value;
                    if (this.feature(sub_name)) {
                        return true;
                    }
                }
            }
            catch (e_2_1) { e_2 = { error: e_2_1 }; }
            finally {
                try {
                    if (names_1_1 && !names_1_1.done && (_a = names_1.return)) _a.call(names_1);
                }
                finally { if (e_2) throw e_2.error; }
            }
            return false;
        }
    };
    return FCSClient;
}());
exports.FCSClient = FCSClient;
exports.default = new FCSClient();
