"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var FCSClient_1 = require("./FCSClient");
describe('getActiveFeatures/setActiveFeatures', function () {
    test('Expect to return with getter the same list of features as defined with setter', function () {
        var features = ['my-feature', 'my-feature2', 'my-feature3'];
        FCSClient_1.default.setActiveFeatures(features);
        expect(FCSClient_1.default.getActiveFeatures()).toEqual(features);
    });
});
describe('getBodyCssClasses', function () {
    test('Expect to return list of css classes from list defined with setter', function () {
        var features = ['my-feature', 'my-feature2', 'my-feature3'];
        FCSClient_1.default.setActiveFeatures(features);
        expect(FCSClient_1.default.getBodyCssClasses()).toEqual('fcs-my-feature fcs-my-feature2 fcs-my-feature3');
    });
    test('Expect to return list of css classes from argument', function () {
        var features = ['my-feature', 'my-feature2'];
        expect(FCSClient_1.default.getBodyCssClasses(features)).toEqual('fcs-my-feature fcs-my-feature2');
    });
    test('Expect to automatically turn slashes into double dashes in names of returned CSS classes', function () {
        var features = ['test/my-feature', 'test/my-feature2'];
        expect(FCSClient_1.default.getBodyCssClasses(features)).toEqual('fcs-test--my-feature fcs-test--my-feature2');
    });
});
describe('feature', function () {
    test('Expect to return true if feature is present among active features defined with setter', function () {
        var features = ['my-feature', 'my-feature2', 'my-feature3'];
        FCSClient_1.default.setActiveFeatures(features);
        expect(FCSClient_1.default.feature('my-feature')).toBe(true);
    });
    test('Expect to return false if feature is not present among active features defined with setter', function () {
        var features = ['my-feature'];
        FCSClient_1.default.setActiveFeatures(features);
        expect(FCSClient_1.default.feature('my-feature2')).toBe(false);
    });
});
describe('multiFeature', function () {
    test('Expect to return true if feature (string or array) is present among active features defined with setter', function () {
        var features = ['my-feature', 'my-feature2', 'my-feature3'];
        FCSClient_1.default.setActiveFeatures(features);
        expect(FCSClient_1.default.multiFeature('my-feature')).toBe(true);
        expect(FCSClient_1.default.multiFeature(['my-feature'])).toBe(true);
    });
    test('Expect to return false if feature (string or array) is not present among active features defined with setter', function () {
        var features = ['my-feature'];
        FCSClient_1.default.setActiveFeatures(features);
        expect(FCSClient_1.default.multiFeature('my-feature2')).toBe(false);
        expect(FCSClient_1.default.multiFeature(['my-feature2'])).toBe(false);
    });
    test('Expect to return true if any of listed features (comma-separated string or array) is present among active features defined with setter', function () {
        var features = ['my-feature'];
        FCSClient_1.default.setActiveFeatures(features);
        expect(FCSClient_1.default.multiFeature('my-feature,my-feature2')).toBe(true);
        expect(FCSClient_1.default.multiFeature(['my-feature', 'my-feature2'])).toBe(true);
    });
    test('Expect to return false if none of listed features (comma-separated string or array) is present among active features defined with setter', function () {
        var features = ['my-feature3'];
        FCSClient_1.default.setActiveFeatures(features);
        expect(FCSClient_1.default.multiFeature('my-feature,my-feature2')).toBe(false);
        expect(FCSClient_1.default.multiFeature(['my-feature', 'my-feature2'])).toBe(false);
    });
});
describe('turnSlashesIntoDoubleDashes', function () {
    test('Expect to turn all the slashes in the provided string into double dashes', function () {
        expect(FCSClient_1.default.turnSlashesIntoDoubleDashes('a/b/c/d')).toEqual('a--b--c--d');
    });
});
